changeset 98621:835147d28933

* help.el (view-lossage): Fix docstring, lossage is now 300 keys. * kmacro.el (kmacro-edit-lossage): Ditto. * edmacro.el (edit-kbd-macro): Ditto.
author Romain Francoise <romain@orebokech.com>
date Sat, 11 Oct 2008 18:43:38 +0000
parents 9c8d02adc5c4
children 99b9163e937f
files lisp/ChangeLog lisp/edmacro.el lisp/help.el lisp/kmacro.el
diffstat 4 files changed, 10 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/ChangeLog	Sat Oct 11 18:35:15 2008 +0000
+++ b/lisp/ChangeLog	Sat Oct 11 18:43:38 2008 +0000
@@ -1,3 +1,9 @@
+2008-10-11  Romain Francoise  <romain@orebokech.com>
+
+	* help.el (view-lossage): Fix docstring, lossage is now 300 keys.
+	* kmacro.el (kmacro-edit-lossage): Ditto.
+	* edmacro.el (edit-kbd-macro): Ditto.
+
 2008-10-11  Ulf Jasper  <ulf@web.de>
 
 	* net/newst-treeview.el (newsticker--treeview-list-sort-by-column):
--- a/lisp/help.el	Sat Oct 11 18:35:15 2008 +0000
+++ b/lisp/help.el	Sat Oct 11 18:43:38 2008 +0000
@@ -453,7 +453,7 @@
   (view-help-file "MORE.STUFF"))
 
 (defun view-lossage ()
-  "Display last 100 input keystrokes.
+  "Display last 300 input keystrokes.
 
 To record all your input on a file, use `open-dribble-file'."
   (interactive)
--- a/lisp/kmacro.el	Sat Oct 11 18:35:15 2008 +0000
+++ b/lisp/kmacro.el	Sat Oct 11 18:43:38 2008 +0000
@@ -895,7 +895,7 @@
 
 
 (defun kmacro-edit-lossage ()
-  "Edit most recent 100 keystrokes as a keyboard macro."
+  "Edit most recent 300 keystrokes as a keyboard macro."
   (interactive)
   (kmacro-push-ring)
   (edit-kbd-macro "\C-hl"))
--- a/lisp/edmacro.el	Sat Oct 11 18:35:15 2008 +0000
+++ b/lisp/edmacro.el	Sat Oct 11 18:43:38 2008 +0000
@@ -37,7 +37,7 @@
 ;;  * `M-x' followed by a command name, to edit a named command
 ;;    whose definition is a keyboard macro.
 ;;
 ;;  * `C-h l' (view-lossage), to edit the 100 most recent keystrokes
 ;;    and install them as the "current" macro.
 ;;
 ;;  * any key sequence whose definition is a keyboard macro.
@@ -96,7 +96,7 @@
   "Edit a keyboard macro.
 At the prompt, type any key sequence which is bound to a keyboard macro.
 Or, type `C-x e' or RET to edit the last keyboard macro, `C-h l' to edit
-the last 100 keystrokes as a keyboard macro, or `M-x' to edit a macro by
+the last 300 keystrokes as a keyboard macro, or `M-x' to edit a macro by
 its command name.
 With a prefix argument, format the macro in a more concise way."
   (interactive "kKeyboard macro to edit (C-x e, M-x, C-h l, or keys): \nP")
@@ -37,7 +37,7 @@
 ;;    whose definition is a keyboard macro.
 ;;
-;;  * `C-h l' (view-lossage), to edit the 100 most recent keystrokes
+;;  * `C-h l' (view-lossage), to edit the 300 most recent keystrokes
 ;;    and install them as the "current" macro.
 ;;